<?php
//* Start the engine
include_once( get_template_directory() . '/lib/init.php' );

//* Setup Genesis Responsive Slider defaults
include_once( get_stylesheet_directory() . '/lib/includes/theme-defaults.php' );

//* Set Localization (do not remove)
load_child_theme_textdomain( 'gigafood', apply_filters( 'child_theme_textdomain', get_stylesheet_directory() . '/lib/languages', 'gigafood' ) );

//* Child theme (do not remove)
define( 'CHILD_THEME_NAME', __( 'GigaFood Theme', 'gigafood' ) );
define( 'CHILD_THEME_URL', 'http://foodbloggingguide.com/' );
define( 'CHILD_THEME_VERSION', '1.0' );

//* Add HTML5 markup structure
add_theme_support( 'html5' );

//* Add Accessibility support
add_theme_support( 'genesis-accessibility', array( 'headings', 'drop-down-menu',  'search-form', 'skip-links', 'rems' ) );

//* Add viewport meta tag for mobile browsers
add_theme_support( 'genesis-responsive-viewport' );

//* Enqueue Javascript files
add_action( 'wp_enqueue_scripts', 'gigafood_enqueue_scripts' );
function gigafood_enqueue_scripts() {

	wp_enqueue_script( 'gigafood-responsive-menu', get_stylesheet_directory_uri() . '/lib/js/responsive-menu.js', array( 'jquery' ), '1.0.0', true );
}

//* Enqueue CSS files
add_action( 'wp_enqueue_scripts', 'gigafood_enqueue_styles' );
function gigafood_enqueue_styles() {
	wp_enqueue_style( 'google-font', '//fonts.googleapis.com/css?family=Rajdhani:400,500,700', array(), CHILD_THEME_VERSION );
	wp_enqueue_style( 'gigafood-dashicons-style', get_stylesheet_uri(), array('dashicons'), '1.0' );
	wp_enqueue_style( 'gigafood-genericons-style', get_stylesheet_directory_uri() . '/lib/font/genericons.css' );
}

//* Add new image sizes
add_image_size( 'small-square', 80, 80, TRUE );
add_image_size( 'large-square', 150, 150, TRUE );
add_image_size( 'feature-image', 360, 150, TRUE );
add_image_size( 'home-slider', 760, 350, TRUE );
add_image_size( 'tabs', 200, 280, TRUE );

//* Add support for custom background
add_theme_support( 'custom-background' );

//* Add support for custom header
add_theme_support( 'custom-header', array(
	'header_image'    => '',
	'header-selector' => '.site-title a',
	'header-text'     => false,
	'width'           => 320,
	'height'          => 110,
) );

//* Add support for 3-column footer widgets
add_theme_support( 'genesis-footer-widgets', 3 );

//* Add front page sidebar
add_action( 'genesis_after_header', 'gigafood_frontpage_sidebar' );
function gigafood_frontpage_sidebar() {

	if ( ! is_front_page() || ! is_active_sidebar( 'front-sidebar' ))
		return;
	remove_action( 'genesis_sidebar', 'genesis_do_sidebar' );
	add_action( 'genesis_sidebar', 'gigafood_do_sidebar' );
}

function gigafood_do_sidebar() {

	dynamic_sidebar( 'front-sidebar' );
}

//* Create additional color style options
add_theme_support( 'genesis-style-selector', array(
	'gigafood-blue'		=>	__( 'Blue', 'gigafood' ),
	'gigafood-bronze'	=>	__( 'Bronze', 'gigafood' ),
	'gigafood-gold'		=>	__( 'Gold', 'gigafood' ),
	'gigafood-orange'	=>	__( 'Orange', 'gigafood' ),
	'gigafood-purple'	=>	__( 'Purple', 'gigafood' ),
	'gigafood-red'		=>	__( 'Red', 'gigafood' ),
) );

//* Customize the entry meta in the entry header
add_filter( 'genesis_post_info', 'gigafood_post_info_filter' );
function gigafood_post_info_filter($post_info) {
	$post_info = '[post_date] [post_author_posts_link] [post_comments] [post_edit]';
	return $post_info;
}

//* Add single post navigation
add_action( 'genesis_after_entry', 'genesis_prev_next_post_nav', 9 );

//* Add before header widget area to home page
add_action( 'genesis_before', 'gigafood_before_header' ); 
function gigafood_before_header() {

	if ( ! is_front_page() )
    	return;

	genesis_widget_area( 'before-header', array(
		'before' => '<div class="before-header widget-area"><div class="wrap">',
		'after'  => '</div></div>',
    ) );

}

//* Add before post widget area to single post page
add_action( 'genesis_before_entry', 'gigafood_before_entry'  ); 
function gigafood_before_entry() {

    if ( ! is_singular( 'post' ) )
    	return;

    genesis_widget_area( 'before-entry', array(
		'before' => '<div class="before-entry widget-area"><div class="wrap">',
		'after'  => '</div></div>',
    ) );

}

//* Add support for after entry widget
add_theme_support( 'genesis-after-entry-widget-area' );

//* Add pre-footer widgets
add_action( 'genesis_before_footer', 'gigafood_pre_footer' ); 
function gigafood_pre_footer() {

    if ( is_active_sidebar( 'prefooter-left' ) || is_active_sidebar( 'prefooter-right' ) ) {

		echo '<div class="prefooter"><div class="wrap">';

    genesis_widget_area( 'prefooter-left', array(
		'before' => '<div class="prefooter-left widget-area one-half first">',
		'after'  => '</div>',
    ) );

    genesis_widget_area( 'prefooter-right', array(
		'before' => '<div class="prefooter-right widget-area one-half">',
		'after'  => '</div>',
    ) );

		echo '</div></div>';
    }
}

//* Include and hook tertiary navigation menu
require_once( CHILD_DIR . '/lib/includes/tertiary-navigation-menu.php' );
add_action( 'genesis_before_footer', 'genesis_do_subnavtwo', 15 );

//* Register Genesis Menus
add_theme_support( 'genesis-menus', array( 'primary'   => __( 'Primary Navigation Menu', 'genesis' ), 'secondary' => __( 'Secondary Navigation Menu', 'genesis' ), 'tertiary' => __( 'Tertiary Navigation Menu', 'genesis' ), ) );

//* Reposition the footer widgets
remove_action( 'genesis_before_footer', 'genesis_footer_widget_areas' );
add_action( 'genesis_after', 'genesis_footer_widget_areas' );

//* Reposition the footer
remove_action( 'genesis_footer', 'genesis_footer_markup_open', 5 );
remove_action( 'genesis_footer', 'genesis_do_footer' );
remove_action( 'genesis_footer', 'genesis_footer_markup_close', 15 );
add_action( 'genesis_after', 'genesis_footer_markup_open', 11 );
add_action( 'genesis_after', 'genesis_do_footer', 12 );
add_action( 'genesis_after', 'genesis_footer_markup_close', 13 );

//* Modify the speak your mind title in comments
add_filter( 'comment_form_defaults', 'gigafood_comment_form_defaults' );
function gigafood_comment_form_defaults( $defaults ) {
 
	$defaults['title_reply'] = __( 'Join the Discussion!' );
	$defaults['comment_notes_before'] = '<p class="comment-box">' . __( 'Please submit your comment with a real name.' );
	$defaults['comment_notes_after'] = '<p class="comment-box">' . __( 'Thanks for your feedback!' );
	return $defaults;
 
}

//* Theme activation message
add_action( 'admin_notices', 'gigafood_welcome' );
function gigafood_welcome() {
	global $pagenow;
	if ( is_admin() && isset($_GET['activated'] ) && $pagenow == "themes.php" ) {
		$settings = sprintf( __( '<strong>Awesome!</strong> You are now using the ' . CHILD_THEME_NAME . ' WP theme. Configure your settings via the <a href="%s" title="Genesis Framework Settings">Genesis settings page</a>. If you have any questions, read the theme documentation bundled with the theme ZIP file or contact <strong>http://xtrapunch.com</strong>', 'gigafood' ) , admin_url( 'admin.php?page=genesis' ) );
		$output = printf( '<div class="updated"><p>%1$s</p></div>', $settings );
	}
}

//* Register widget areas
genesis_register_sidebar( array(
	'id'          => 'front-sidebar',
	'name'        => __( 'Home Page Sidebar', 'gigafood' ),
	'description' => __( 'This is the frontpage sidebar.', 'gigafood' ),
) );
genesis_register_sidebar( array(
	'id'		=> 'before-header',
	'name'		=> __( 'Before Header', 'gigafood' ),
	'description'	=> __( 'This is the Before Header widget area of the homepage.', 'gigafood' ),
) );
genesis_register_sidebar( array(
	'id'		=> 'before-entry',
	'name'		=> __( 'Before Entry', 'gigafood' ),
	'description'	=> __( 'Widgets in this widget area will display before single postsentries.', 'gigafood' ),
) );
genesis_register_sidebar( array(
	'id'		=> 'home-ticker',
	'name'		=> __( 'Home Page Banner', 'gigafood' ),
	'description'	=> __( 'This is the Home Top widget area. Use it for showing advertisements or new tickers or featured posts.', 'gigafood' ),
) );
genesis_register_sidebar( array(
	'id'		=> 'home-tabs',
	'name'		=> __( 'Home Page Tabs/Content', 'gigafood' ),
	'description'	=> __( 'This is the Home Page Tabs widget area. Use the Featured Posts widget to include the latest posts and/or posts from specific categories on the front page.', 'gigafood' ),
) );
genesis_register_sidebar( array(
	'id'		=> 'home-slider',
	'name'		=> __( 'Home Page Slider', 'gigafood' ),
	'description'	=> __( 'This is the Home Page Slider widget area. Use the Genesis Responsive Slider to showcase your posts/pages.', 'gigafood' ),
) );
genesis_register_sidebar( array(
	'id'		=> 'home-top',
	'name'		=> __( 'Home Page Top', 'gigafood' ),
	'description'	=> __( 'This is the Home Page Top widget area.', 'gigafood' ),
) );
genesis_register_sidebar( array(
	'id'		=> 'home-left',
	'name'		=> __( 'Home Page Left', 'gigafood' ),
	'description'	=> __( 'This is the Home Left widget area.', 'gigafood' ),
) );
genesis_register_sidebar( array(
	'id'		=> 'home-right',
	'name'		=> __( 'Home Page Right', 'gigafood' ),
	'description'	=> __( 'This is the Home Right widget area.', 'gigafood' ),
) );
genesis_register_sidebar( array(
	'id'		=> 'prefooter-left',
	'name'		=> __( 'Before Footer - Left', 'gigafood' ),
	'description'	=> __( 'This is the Pre-Footer Left widget area.', 'gigafood' ),
) );
genesis_register_sidebar( array(
	'id'		=> 'prefooter-right',
	'name'		=> __( 'Before Footer - Right', 'gigafood' ),
	'description'	=> __( 'This is the Pre-Footer Right widget area.', 'gigafood' ),
) );
genesis_register_sidebar( array(
	'id'		=> 'widget-page',
	'name'		=> __( 'Widget Page', 'gigafood' ),
	'description'	=> __( 'This is the widget area for the Widget Page template.', 'gigafood' ),
) );

//* Customize the entire footer
add_filter('genesis_footer_creds_text', 'xtra_footer_creds_text');
function xtra_footer_creds_text($creds) {
	if (is_front_page()) {
	$creds = '[footer_copyright] &mdash; <a href="'. CHILD_THEME_URL .'" target="_blank">' . get_bloginfo('name') . ' &mdash; Powered by WordPress & '. CHILD_THEME_NAME .'</a>';
	} else {
	$creds = '[footer_copyright] &mdash; ' . get_bloginfo('name') . ' &mdash; Powered by WordPress & '. CHILD_THEME_NAME;
	}
	return  $creds;
}
